summaryrefslogtreecommitdiffstats
path: root/Core/Authorization/AccessDecisionManager.php
diff options
context:
space:
mode:
Diffstat (limited to 'Core/Authorization/AccessDecisionManager.php')
-rw-r--r--Core/Authorization/AccessDecisionManager.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/Core/Authorization/AccessDecisionManager.php b/Core/Authorization/AccessDecisionManager.php
index 18c3569..726f62e 100644
--- a/Core/Authorization/AccessDecisionManager.php
+++ b/Core/Authorization/AccessDecisionManager.php
@@ -32,8 +32,8 @@ class AccessDecisionManager implements AccessDecisionManagerInterface
*
* @param VoterInterface[] $voters An array of VoterInterface instances
* @param string $strategy The vote strategy
* @param Boolean $allowIfAllAbstainDecisions Whether to grant access if all voters abstained or not
* @param Boolean $allowIfEqualGrantedDeniedDecisions Whether to grant access if result are equals
*
* @throws \InvalidArgumentException
*/
@@ -50,8 +50,8 @@ class AccessDecisionManager implements AccessDecisionManagerInterface
$this->voters = $voters;
$this->strategy = $strategyMethod;
- $this->allowIfAllAbstainDecisions = (Boolean) $allowIfAllAbstainDecisions;
- $this->allowIfEqualGrantedDeniedDecisions = (Boolean) $allowIfEqualGrantedDeniedDecisions;
+ $this->allowIfAllAbstainDecisions = (bool) $allowIfAllAbstainDecisions;
+ $this->allowIfEqualGrantedDeniedDecisions = (bool) $allowIfEqualGrantedDeniedDecisions;
}
/**
@@ -32,8 +32,8 @@ class AccessDecisionManager implements AccessDecisionManagerInterface
* @param VoterInterface[] $voters An array of VoterInterface instances
* @param string $strategy The vote strategy
- * @param Boolean $allowIfAllAbstainDecisions Whether to grant access if all voters abstained or not
- * @param Boolean $allowIfEqualGrantedDeniedDecisions Whether to grant access if result are equals
+ * @param bool $allowIfAllAbstainDecisions Whether to grant access if all voters abstained or not
+ * @param bool $allowIfEqualGrantedDeniedDecisions Whether to grant access if result are equals
*
* @throws \InvalidArgumentException